<div align="center">

[![Logo Pratik](https://raw.githubusercontent.com/LassaInora/LassaInora/refs/heads/project-icon/pratik/logo.png)](https://pypi.org/project/pratik/)
# Pratik
[![LassaInora - Pratik](https://img.shields.io/static/v1?label=LassaInora&message=Pratik&color=yellow&logo=github)](https://github.com/LassaInora/Pratik "Go to GitHub repo")
[![GitHub tag](https://img.shields.io/github/tag/LassaInora/Pratik?include_prereleases=&sort=semver&color=orange)](https://github.com/LassaInora/Pratik/releases/)
[![stars - Pratik](https://img.shields.io/github/stars/LassaInora/Pratik?style=social)](https://github.com/LassaInora/Pratik)
[![forks - Pratik](https://img.shields.io/github/forks/LassaInora/Pratik?style=social)](https://github.com/LassaInora/Pratik)

[![PyPI version](https://badge.fury.io/py/Pratik.svg)](https://badge.fury.io/py/Pratik)
[![Supported Versions](https://img.shields.io/pypi/pyversions/Pratik.svg)](https://pypi.org/project/Pratik)

___

</div>

# Overview
Pratik is a Python library designed to provide multiple practical tools for designing Python scripts. It includes a 
terminal menu manager, a Singleton class, a simple logging tool, a progress bar, and much more!

# How to use
## Installation
- Unix/ macOS : `python3 -m pip install --upgrade Pratik`
- Windows : `py -m pip install --upgrade Pratik`

## Library Interface

Pratik is a library of various functions and classes helping to program more efficiently and more intuitively.  
→ [How to use the library?](https://github.com/LassaInora/Pratik/wiki)

# Contributors

### Library created by

* [Axelle VIANDIER (aka. LassaInora)](https://github.com/LassaInora)

# Licence

This project is licensed under the [GNU General Public License v3](LICENSE).